return {
  {
    "stevearc/conform.nvim",
    -- event = 'BufWritePre', -- uncomment for format on save
    opts = require "configs.conform",
  },

  -- These are some examples, uncomment them if you want to see them work!
  {
    "neovim/nvim-lspconfig",
    config = function()
      require "configs.lspconfig"
    end,
  },

  {
    "nvimtools/none-ls.nvim",
    ft = "go",
    opts = function ()
      return require "configs.none-ls"
    end,
  },

  {
    "williamboman/mason.nvim",
    opts = {
      ensure_installed = {
        "gopls",
        "pyright",
        "typescript-language-server",
        "tailwindcss-language-server",
        "prettierd",
        "eslint-lsp",
        "ltex-ls",
      }
    }
  },

  {
  	"nvim-treesitter/nvim-treesitter",
  	opts = {
  		ensure_installed = {
  			"vim",
        "lua",
        "vimdoc",
        "html",
        "css",
        "typescript",
        "go",
        "rust",
        "python",
        "tsx",
        "markdown"
  		},
      highlight = { enable = true },
  	},
  },

  {
    "ray-x/go.nvim",
    config = function()
      require("go").setup()
    end,
    event = {"CmdlineEnter"},
    ft = {"go", 'gomod'},
    build = ':lua require("go.install").update_all_sync()' -- if you need to install/update all binaries
  },
  {
    "kdheepak/lazygit.nvim",
    cmd = {
      "LazyGit",
      "LazyGitConfig",
      "LazyGitCurrentFile",
      "LazyGitFilter",
      "LazyGitFilterCurrentFile",
    },
    -- optional for floating window border decoration
    dependencies = {
      "nvim-lua/plenary.nvim",
    },
    -- setting the keybinding for LazyGit with 'keys' is recommended in
    -- order to load the plugin when the command is run for the first time
    keys = {
      { "<leader>lg", "<cmd>LazyGit<cr>", desc = "LazyGit" }
    }
  },
  {
    'MeanderingProgrammer/render-markdown.nvim',
    ft = {"markdown"},
    dependencies = { 'nvim-treesitter/nvim-treesitter', 'echasnovski/mini.nvim' }, -- if you use the mini.nvim suite
    config = function()
        local opts = require("configs.render-markdown")
        require("render-markdown").setup(opts)
    end,
  },
  {
    "f3fora/cmp-spell",
    dependencies = { "hrsh7th/nvim-cmp" },
    event = "InsertEnter",
    config = function()
      local cmp = require("cmp")

      cmp.setup({
        sources = cmp.config.sources({
          { name = "spell" },       -- Add spell source
          { name = "buffer" },
          { name = "path" },
          { name = "nvim_lsp" },
          -- ... your other sources
        }),
        -- Optional: enable spelling suggestions only in relevant filetypes
        enabled = function()
          local ft = vim.bo.filetype
          return vim.o.spell and (ft == "markdown" or ft == "text" or ft == "tex")
        end,
      })
    end,
  },
  {
    "liuchengxu/vista.vim",
    lazy = false,
  },
}
